sjkabc
======

|docs-develop| |docs-master| |build-status|

.. |docs-develop| image:: https://readthedocs.org/projects/sjkabc/badge/?version=develop
    :alt: Documentation status
    :scale: 100%
    :target: https://sjkabc.readthedocs.org/en/develop/?badge=develop

.. |docs-master| image:: https://readthedocs.org/projects/sjkabc/badge/?version=master
    :alt: Documentation status
    :scale: 100%
    :target: https://sjkabc.readthedocs.org/en/master/?badge=master

.. |build-status| image:: https://travis-ci.org/sjktje/sjkabc.svg?branch=develop
    :alt: Build status
    :scale: 100%
    :target: https://travis-ci.org/sjktje/sjkabc
